@@ -14,6 +14,8 @@
 #include <QDesktopServices>
 //#include <QAbstractKineticScroller>
 
+//#define CAMERA
+
 #ifdef CAMERA
 #include "camera.h"
 #endif
@@ -48,6 +50,7 @@ protected:
 DetailWindow::DetailWindow(Target * _target, const QString & groupName, int istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
 {
+	setWindowTitle("Wallet");
 
 //	this->setAttribute(Qt::WA_NativeWindow);
 
@@ -131,10 +134,9 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		menuBar()->addAction(tr("Delete Back Pict."), this, SLOT(deleteCardBack()));
 		menuBar()->addAction(tr("Modify fields"), this, SLOT(modifyFields()));
 
-		//menuBar()->addAction(tr("Camera"), this, SLOT(takePicture()));
-
-		//TODO menuBar()->addAction("Delete field", this, SLOT(addNewField()));
-		//TODO menuBar()->addAction("Modify field", this, SLOT(addNewField()));
+#ifdef CAMERA
+		menuBar()->addAction(tr("Camera"), this, SLOT(takePicture()));
+#endif
 	}
 	else {
 		menuBar()->addAction(tr("New Card"), this, SLOT(_newTarget()));
@@ -200,9 +202,12 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 		groupLineEdit->setText (this->target->groupName);
 
+
 	}
 	else {
-		this->setWindowTitle (_target->name);
+		QString title ("Wallet - ");
+		title.append (_target->name);
+		this->setWindowTitle (title);
 	}
 
 	if (edit) {
@@ -361,6 +366,12 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 
 	orientationChanged(0);
+
+	if (edit) {
+		centralWidget->setFocus ();
+		focusNextChild();
+		//nameLineEdit->setFocus ();
+	}
 }
 
 void DetailWindow::modifyFields() {
@@ -1044,19 +1055,15 @@ void DetailWindow::cardBack()
 }
 
 void DetailWindow::photoTake (QImage* image) {
-	if (currentImageBackN) delete currentImageBackN;
-
-	currentImageBackN = new QImage (*image);
-
-	imageBackLabel->setPixmap(QPixmap::fromImage (*currentImageBackN));
-
+	if (currentImageN) delete currentImageN;
+	currentImageN = new QImage (*image);
+	imageLabel->setPixmap(QPixmap::fromImage (*currentImageN));
 	deleteBack = false;
 }
 
 void DetailWindow::takePicture () {
 #ifdef CAMERA
 	QCamera * cam = new QCamera;
-
 	connect (cam, SIGNAL(photoReady (QImage*)), this, SLOT(photoTake(QImage*)));
 #endif
 }
@@ -1104,6 +1111,8 @@ void DetailWindow::closeEvent(QCloseEvent *event) {
 CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 		QDialog((QWidget*)paTarget)
 {
+	setWindowTitle("Wallet");
+
 	pos = 0;
 	this->target = target;
 	this->parent = paTarget;
@@ -1236,10 +1245,13 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 void CreateFieldDialog::update () {
 	if (pos < fields.length()) {
 		int type = typeLineEdit->itemData(typeLineEdit->currentIndex()).toInt();
-		int order = QVariant (orderEdit->text()).toInt();
-		fields[pos]->name = nameLineEdit->text();
-		fields[pos]->type = type;
-		fields[pos]->order = order;
+		if (orderEdit->isModified() || nameLineEdit->isModified() || type != fields[pos]->type) {
+			int order = QVariant (orderEdit->text()).toInt();
+			fields[pos]->name = nameLineEdit->text();
+			fields[pos]->type = type;
+			fields[pos]->order = order;
+			_fieldsChanged = true;
+		}
 	}
 }
 
