@@ -11,7 +11,7 @@
 
 int main(int argc, char *argv[])
 {
-	QCoreApplication::setAttribute(Qt::AA_NativeWindows);
+//	QCoreApplication::setAttribute(Qt::AA_NativeWindows);
 
     QApplication app(argc, argv);
 
@@ -23,7 +23,7 @@ int main(int argc, char *argv[])
     else
     	lang = QLocale::system().name();
 
-    qDebug () << " SYST = " << QLibraryInfo::location(QLibraryInfo::TranslationsPath) << " IN " << lang;
+    //qDebug () << " SYST = " << QLibraryInfo::location(QLibraryInfo::TranslationsPath) << " IN " << lang;
 
     QTranslator qtTranslator;
     qtTranslator.load(QString("qt_") + lang,
@@ -33,7 +33,10 @@ int main(int argc, char *argv[])
     //qDebug () << "LANGUAGE " << QLocale::system().name();
 
     QTranslator myappTranslator;
-    myappTranslator.load(QString (":/resources/locale/qtwallet_") + lang);
+    qtTranslator.load(QString("/usr/share/qtwallet/translations/qtwallet_") + lang,
+            QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+
+    //myappTranslator.load(QString (":/resources/locale/qtwallet_") + lang);
     app.installTranslator(&myappTranslator);
 
 	eWallet * w = new eWallet();
